.loader {
  animation: spinAround 500ms infinite linear;
  border: 2px solid var(--bulma-border);
  border-radius: var(--bulma-radius-rounded);
  border-right-color: transparent;
  border-top-color: transparent;
  content: "";
  display: block;
  height: 1em;
  position: relative;
  width: 1em;
}

/*# sourceMappingURL=loader.css.map */
