:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.content:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.content {
  --bulma-content-heading-color: var(--bulma-text-strong);
  --bulma-content-heading-weight: var(--bulma-weight-extrabold);
  --bulma-content-heading-line-height: 1.125;
  --bulma-content-block-margin-bottom: 1em;
  --bulma-content-blockquote-background-color: var(--bulma-background);
  --bulma-content-blockquote-border-left: 5px solid var(--bulma-border);
  --bulma-content-blockquote-padding: 1.25em 1.5em;
  --bulma-content-pre-padding: 1.25em 1.5em;
  --bulma-content-table-cell-border: 1px solid var(--bulma-border);
  --bulma-content-table-cell-border-width: 0 0 1px;
  --bulma-content-table-cell-padding: 0.5em 0.75em;
  --bulma-content-table-cell-heading-color: var(--bulma-text-strong);
  --bulma-content-table-head-cell-border-width: 0 0 2px;
  --bulma-content-table-head-cell-color: var(--bulma-text-strong);
  --bulma-content-table-body-last-row-cell-border-bottom-width: 0;
  --bulma-content-table-foot-cell-border-width: 2px 0 0;
  --bulma-content-table-foot-cell-color: var(--bulma-text-strong);
}

.content li + li {
  margin-top: 0.25em;
}
.content p:not(:last-child),
.content dl:not(:last-child),
.content ol:not(:last-child),
.content ul:not(:last-child),
.content blockquote:not(:last-child),
.content pre:not(:last-child),
.content table:not(:last-child) {
  margin-bottom: var(--bulma-content-block-margin-bottom);
}
.content h1,
.content h2,
.content h3,
.content h4,
.content h5,
.content h6 {
  color: var(--bulma-content-heading-color);
  font-weight: var(--bulma-content-heading-weight);
  line-height: var(--bulma-content-heading-line-height);
}
.content h1 {
  font-size: 2em;
  margin-bottom: 0.5em;
}
.content h1:not(:first-child) {
  margin-top: 1em;
}
.content h2 {
  font-size: 1.75em;
  margin-bottom: 0.5714em;
}
.content h2:not(:first-child) {
  margin-top: 1.1428em;
}
.content h3 {
  font-size: 1.5em;
  margin-bottom: 0.6666em;
}
.content h3:not(:first-child) {
  margin-top: 1.3333em;
}
.content h4 {
  font-size: 1.25em;
  margin-bottom: 0.8em;
}
.content h5 {
  font-size: 1.125em;
  margin-bottom: 0.8888em;
}
.content h6 {
  font-size: 1em;
  margin-bottom: 1em;
}
.content blockquote {
  background-color: var(--bulma-content-blockquote-background-color);
  border-inline-start: var(--bulma-content-blockquote-border-left);
  padding: var(--bulma-content-blockquote-padding);
}
.content ol {
  list-style-position: outside;
  margin-inline-start: 2em;
}
.content ol:not(:first-child) {
  margin-top: 1em;
}
.content ol:not([type]) {
  list-style-type: decimal;
}
.content ol:not([type]).is-lower-alpha {
  list-style-type: lower-alpha;
}
.content ol:not([type]).is-lower-roman {
  list-style-type: lower-roman;
}
.content ol:not([type]).is-upper-alpha {
  list-style-type: upper-alpha;
}
.content ol:not([type]).is-upper-roman {
  list-style-type: upper-roman;
}
.content ul {
  list-style: disc outside;
  margin-inline-start: 2em;
}
.content ul:not(:first-child) {
  margin-top: 1em;
}
.content ul ul {
  list-style-type: circle;
  margin-bottom: 0.25em;
  margin-top: 0.25em;
}
.content ul ul ul {
  list-style-type: square;
}
.content dd {
  margin-inline-start: 2em;
}
.content figure:not([class]) {
  margin-left: 2em;
  margin-right: 2em;
  text-align: center;
}
.content figure:not([class]):not(:first-child) {
  margin-top: 2em;
}
.content figure:not([class]):not(:last-child) {
  margin-bottom: 2em;
}
.content figure:not([class]) img {
  display: inline-block;
}
.content figure:not([class]) figcaption {
  font-style: italic;
}
.content pre {
  -webkit-overflow-scrolling: touch;
  overflow-x: auto;
  padding: var(--bulma-content-pre-padding);
  white-space: pre;
  word-wrap: normal;
}
.content sup,
.content sub {
  font-size: 75%;
}
.content table td,
.content table th {
  border: var(--bulma-content-table-cell-border);
  border-width: var(--bulma-content-table-cell-border-width);
  padding: var(--bulma-content-table-cell-padding);
  vertical-align: top;
}
.content table th {
  color: var(--bulma-content-table-cell-heading-color);
}
.content table th:not([align]) {
  text-align: inherit;
}
.content table thead td,
.content table thead th {
  border-width: var(--bulma-content-table-head-cell-border-width);
  color: var(--bulma-content-table-head-cell-color);
}
.content table tfoot td,
.content table tfoot th {
  border-width: var(--bulma-content-table-foot-cell-border-width);
  color: var(--bulma-content-table-foot-cell-color);
}
.content table tbody tr:last-child td,
.content table tbody tr:last-child th {
  border-bottom-width: var(--bulma-content-table-body-last-row-cell-border-bottom-width);
}
.content .tabs li + li {
  margin-top: 0;
}
.content.is-small {
  font-size: var(--bulma-size-small);
}
.content.is-normal {
  font-size: var(--bulma-size-normal);
}
.content.is-medium {
  font-size: var(--bulma-size-medium);
}
.content.is-large {
  font-size: var(--bulma-size-large);
}

/*# sourceMappingURL=content.css.map */
