:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.buttons:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.button {
  align-items: center;
  appearance: none;
  border-color: transparent;
  border-style: solid;
  border-width: var(--bulma-control-border-width);
  border-radius: var(--bulma-control-radius);
  box-shadow: none;
  display: inline-flex;
  font-size: var(--bulma-control-size);
  height: var(--bulma-control-height);
  justify-content: flex-start;
  line-height: var(--bulma-control-line-height);
  padding-bottom: var(--bulma-control-padding-vertical);
  padding-left: var(--bulma-control-padding-horizontal);
  padding-right: var(--bulma-control-padding-horizontal);
  padding-top: var(--bulma-control-padding-vertical);
  position: relative;
  transition-duration: var(--bulma-duration);
  transition-property: background-color, border-color, box-shadow, color;
  vertical-align: top;
}
.button:focus, .button:focus-visible, .button:focus-within, .is-focused.button, .button:active, .is-active.button {
  outline: none;
}
[disabled].button, fieldset[disabled] .button {
  cursor: not-allowed;
}

.button.is-loading::after {
  animation: spinAround 500ms infinite linear;
  border: 2px solid var(--bulma-loading-color);
  border-radius: var(--bulma-radius-rounded);
  border-right-color: transparent;
  border-top-color: transparent;
  content: "";
  display: block;
  height: 1em;
  position: relative;
  width: 1em;
}

.button {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.button {
  --bulma-button-family: false;
  --bulma-button-weight: var(--bulma-weight-medium);
  --bulma-button-border-color: var(--bulma-border);
  --bulma-button-border-style: solid;
  --bulma-button-border-width: var(--bulma-control-border-width);
  --bulma-button-padding-vertical: 0.5em;
  --bulma-button-padding-horizontal: 1em;
  --bulma-button-focus-border-color: var(--bulma-link-focus-border);
  --bulma-button-focus-box-shadow-size: 0 0 0 0.125em;
  --bulma-button-focus-box-shadow-color: hsla(var(--bulma-link-h), var(--bulma-link-s), var(--bulma-link-on-scheme-l), 0.25);
  --bulma-button-active-color: var(--bulma-link-active);
  --bulma-button-active-border-color: var(--bulma-link-active-border);
  --bulma-button-text-color: var(--bulma-text);
  --bulma-button-text-decoration: underline;
  --bulma-button-text-hover-background-color: var(--bulma-background);
  --bulma-button-text-hover-color: var(--bulma-text-strong);
  --bulma-button-ghost-background: none;
  --bulma-button-ghost-border-color: transparent;
  --bulma-button-ghost-color: var(--bulma-link-text);
  --bulma-button-ghost-decoration: none;
  --bulma-button-ghost-hover-color: var(--bulma-link);
  --bulma-button-ghost-hover-decoration: underline;
  --bulma-button-disabled-background-color: var(--bulma-scheme-main);
  --bulma-button-disabled-border-color: var(--bulma-border);
  --bulma-button-disabled-shadow: none;
  --bulma-button-disabled-opacity: 0.5;
  --bulma-button-static-color: var(--bulma-text-weak);
  --bulma-button-static-background-color: var(--bulma-scheme-main-ter);
  --bulma-button-static-border-color: var(--bulma-border);
}

.button {
  --bulma-button-h: var(--bulma-scheme-h);
  --bulma-button-s: var(--bulma-scheme-s);
  --bulma-button-l: var(--bulma-scheme-main-l);
  --bulma-button-background-l: var(--bulma-scheme-main-l);
  --bulma-button-background-l-delta: 0%;
  --bulma-button-hover-background-l-delta: var(--bulma-hover-background-l-delta);
  --bulma-button-active-background-l-delta: var(--bulma-active-background-l-delta);
  --bulma-button-color-l: var(--bulma-text-strong-l);
  --bulma-button-border-l: var(--bulma-border-l);
  --bulma-button-border-l-delta: 0%;
  --bulma-button-hover-border-l-delta: var(--bulma-hover-border-l-delta);
  --bulma-button-active-border-l-delta: var(--bulma-active-border-l-delta);
  --bulma-button-focus-border-l-delta: var(--bulma-focus-border-l-delta);
  --bulma-button-outer-shadow-h: 0;
  --bulma-button-outer-shadow-s: 0%;
  --bulma-button-outer-shadow-l: 20%;
  --bulma-button-outer-shadow-a: 0.05;
  --bulma-loading-color: hsl(var(--bulma-button-h), var(--bulma-button-s), var(--bulma-button-color-l));
  background-color: hsl(var(--bulma-button-h), var(--bulma-button-s), calc(var(--bulma-button-background-l) + var(--bulma-button-background-l-delta)));
  border-color: hsl(var(--bulma-button-h), var(--bulma-button-s), calc(var(--bulma-button-border-l) + var(--bulma-button-border-l-delta)));
  border-style: var(--bulma-button-border-style);
  border-width: var(--bulma-button-border-width);
  box-shadow: 0px 0.0625em 0.125em hsla(var(--bulma-button-outer-shadow-h), var(--bulma-button-outer-shadow-s), var(--bulma-button-outer-shadow-l), var(--bulma-button-outer-shadow-a)), 0px 0.125em 0.25em hsla(var(--bulma-button-outer-shadow-h), var(--bulma-button-outer-shadow-s), var(--bulma-button-outer-shadow-l), var(--bulma-button-outer-shadow-a));
  color: hsl(var(--bulma-button-h), var(--bulma-button-s), var(--bulma-button-color-l));
  cursor: pointer;
  font-weight: var(--bulma-button-weight);
  height: auto;
  justify-content: center;
  padding-bottom: calc(var(--bulma-button-padding-vertical) - var(--bulma-button-border-width));
  padding-left: calc(var(--bulma-button-padding-horizontal) - var(--bulma-button-border-width));
  padding-right: calc(var(--bulma-button-padding-horizontal) - var(--bulma-button-border-width));
  padding-top: calc(var(--bulma-button-padding-vertical) - var(--bulma-button-border-width));
  text-align: center;
  white-space: nowrap;
}
.button strong {
  color: inherit;
}
.button .icon, .button .icon.is-small, .button .icon.is-medium, .button .icon.is-large {
  height: 1.5em;
  width: 1.5em;
}
.button .icon:first-child:not(:last-child) {
  margin-inline-start: calc(-0.5 * var(--bulma-button-padding-horizontal));
  margin-inline-end: calc(var(--bulma-button-padding-horizontal) * 0.25);
}
.button .icon:last-child:not(:first-child) {
  margin-inline-start: calc(var(--bulma-button-padding-horizontal) * 0.25);
  margin-inline-end: calc(-0.5 * var(--bulma-button-padding-horizontal));
}
.button .icon:first-child:last-child {
  margin-inline-start: calc(-0.5 * var(--bulma-button-padding-horizontal));
  margin-inline-end: calc(-0.5 * var(--bulma-button-padding-horizontal));
}
.button:hover, .button.is-hovered {
  --bulma-button-background-l-delta: var(--bulma-button-hover-background-l-delta);
  --bulma-button-border-l-delta: var(--bulma-button-hover-border-l-delta);
}
.button:focus-visible, .button.is-focused {
  --bulma-button-border-width: 1px;
  border-color: hsl(var(--bulma-focus-h), var(--bulma-focus-s), var(--bulma-focus-l));
  box-shadow: var(--bulma-focus-shadow-size) hsla(var(--bulma-focus-h), var(--bulma-focus-s), var(--bulma-focus-l), var(--bulma-focus-shadow-alpha));
}
.button:active, .button.is-active {
  --bulma-button-background-l-delta: var(--bulma-button-active-background-l-delta);
  --bulma-button-border-l-delta: var(--bulma-button-active-border-l-delta);
  --bulma-button-outer-shadow-a: 0;
}
.button[disabled], fieldset[disabled] .button {
  background-color: var(--bulma-button-disabled-background-color);
  border-color: var(--bulma-button-disabled-border-color);
  box-shadow: var(--bulma-button-disabled-shadow);
  opacity: var(--bulma-button-disabled-opacity);
}
.button.is-white {
  --bulma-button-h: var(--bulma-white-h);
  --bulma-button-s: var(--bulma-white-s);
  --bulma-button-l: var(--bulma-white-l);
  --bulma-button-background-l: var(--bulma-white-l);
  --bulma-button-border-l: var(--bulma-white-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-white-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-white:focus-visible, .button.is-white.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-white.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-white.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-white[disabled], fieldset[disabled] .button.is-white {
  background-color: var(--bulma-white);
  border-color: var(--bulma-white);
  box-shadow: none;
}
.button.is-black {
  --bulma-button-h: var(--bulma-black-h);
  --bulma-button-s: var(--bulma-black-s);
  --bulma-button-l: var(--bulma-black-l);
  --bulma-button-background-l: var(--bulma-black-l);
  --bulma-button-border-l: var(--bulma-black-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-black-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-black:focus-visible, .button.is-black.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-black.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-black.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-black[disabled], fieldset[disabled] .button.is-black {
  background-color: var(--bulma-black);
  border-color: var(--bulma-black);
  box-shadow: none;
}
.button.is-light {
  --bulma-button-h: var(--bulma-light-h);
  --bulma-button-s: var(--bulma-light-s);
  --bulma-button-l: var(--bulma-light-l);
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-border-l: var(--bulma-light-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-light-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-light:focus-visible, .button.is-light.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-light.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-light.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-light[disabled], fieldset[disabled] .button.is-light {
  background-color: var(--bulma-light);
  border-color: var(--bulma-light);
  box-shadow: none;
}
.button.is-dark {
  --bulma-button-h: var(--bulma-dark-h);
  --bulma-button-s: var(--bulma-dark-s);
  --bulma-button-l: var(--bulma-dark-l);
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-border-l: var(--bulma-dark-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-dark-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-dark:focus-visible, .button.is-dark.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-dark.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-dark.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-dark[disabled], fieldset[disabled] .button.is-dark {
  background-color: var(--bulma-dark);
  border-color: var(--bulma-dark);
  box-shadow: none;
}
.button.is-text {
  --bulma-button-h: var(--bulma-text-h);
  --bulma-button-s: var(--bulma-text-s);
  --bulma-button-l: var(--bulma-text-l);
  --bulma-button-background-l: var(--bulma-text-l);
  --bulma-button-border-l: var(--bulma-text-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-text-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-text:focus-visible, .button.is-text.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-text.is-light {
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-color-l: var(--bulma-text-light-invert-l);
}
.button.is-text.is-dark {
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-color-l: var(--bulma-text-dark-invert-l);
}
.button.is-text.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-text.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-text[disabled], fieldset[disabled] .button.is-text {
  background-color: var(--bulma-text);
  border-color: var(--bulma-text);
  box-shadow: none;
}
.button.is-primary {
  --bulma-button-h: var(--bulma-primary-h);
  --bulma-button-s: var(--bulma-primary-s);
  --bulma-button-l: var(--bulma-primary-l);
  --bulma-button-background-l: var(--bulma-primary-l);
  --bulma-button-border-l: var(--bulma-primary-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-primary-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-primary:focus-visible, .button.is-primary.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-primary.is-light {
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-color-l: var(--bulma-primary-light-invert-l);
}
.button.is-primary.is-dark {
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-color-l: var(--bulma-primary-dark-invert-l);
}
.button.is-primary.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-primary.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-primary[disabled], fieldset[disabled] .button.is-primary {
  background-color: var(--bulma-primary);
  border-color: var(--bulma-primary);
  box-shadow: none;
}
.button.is-link {
  --bulma-button-h: var(--bulma-link-h);
  --bulma-button-s: var(--bulma-link-s);
  --bulma-button-l: var(--bulma-link-l);
  --bulma-button-background-l: var(--bulma-link-l);
  --bulma-button-border-l: var(--bulma-link-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-link-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-link:focus-visible, .button.is-link.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-link.is-light {
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-color-l: var(--bulma-link-light-invert-l);
}
.button.is-link.is-dark {
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-color-l: var(--bulma-link-dark-invert-l);
}
.button.is-link.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-link.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-link[disabled], fieldset[disabled] .button.is-link {
  background-color: var(--bulma-link);
  border-color: var(--bulma-link);
  box-shadow: none;
}
.button.is-info {
  --bulma-button-h: var(--bulma-info-h);
  --bulma-button-s: var(--bulma-info-s);
  --bulma-button-l: var(--bulma-info-l);
  --bulma-button-background-l: var(--bulma-info-l);
  --bulma-button-border-l: var(--bulma-info-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-info-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-info:focus-visible, .button.is-info.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-info.is-light {
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-color-l: var(--bulma-info-light-invert-l);
}
.button.is-info.is-dark {
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-color-l: var(--bulma-info-dark-invert-l);
}
.button.is-info.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-info.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-info[disabled], fieldset[disabled] .button.is-info {
  background-color: var(--bulma-info);
  border-color: var(--bulma-info);
  box-shadow: none;
}
.button.is-success {
  --bulma-button-h: var(--bulma-success-h);
  --bulma-button-s: var(--bulma-success-s);
  --bulma-button-l: var(--bulma-success-l);
  --bulma-button-background-l: var(--bulma-success-l);
  --bulma-button-border-l: var(--bulma-success-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-success-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-success:focus-visible, .button.is-success.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-success.is-light {
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-color-l: var(--bulma-success-light-invert-l);
}
.button.is-success.is-dark {
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-color-l: var(--bulma-success-dark-invert-l);
}
.button.is-success.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-success.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-success[disabled], fieldset[disabled] .button.is-success {
  background-color: var(--bulma-success);
  border-color: var(--bulma-success);
  box-shadow: none;
}
.button.is-warning {
  --bulma-button-h: var(--bulma-warning-h);
  --bulma-button-s: var(--bulma-warning-s);
  --bulma-button-l: var(--bulma-warning-l);
  --bulma-button-background-l: var(--bulma-warning-l);
  --bulma-button-border-l: var(--bulma-warning-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-warning-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-warning:focus-visible, .button.is-warning.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-warning.is-light {
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-color-l: var(--bulma-warning-light-invert-l);
}
.button.is-warning.is-dark {
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-color-l: var(--bulma-warning-dark-invert-l);
}
.button.is-warning.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-warning.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-warning[disabled], fieldset[disabled] .button.is-warning {
  background-color: var(--bulma-warning);
  border-color: var(--bulma-warning);
  box-shadow: none;
}
.button.is-danger {
  --bulma-button-h: var(--bulma-danger-h);
  --bulma-button-s: var(--bulma-danger-s);
  --bulma-button-l: var(--bulma-danger-l);
  --bulma-button-background-l: var(--bulma-danger-l);
  --bulma-button-border-l: var(--bulma-danger-l);
  --bulma-button-border-width: 0px;
  --bulma-button-color-l: var(--bulma-danger-invert-l);
  --bulma-button-outer-shadow-a: 0;
}
.button.is-danger:focus-visible, .button.is-danger.is-focused {
  --bulma-button-border-width: 1px;
}
.button.is-danger.is-light {
  --bulma-button-background-l: var(--bulma-light-l);
  --bulma-button-color-l: var(--bulma-danger-light-invert-l);
}
.button.is-danger.is-dark {
  --bulma-button-background-l: var(--bulma-dark-l);
  --bulma-button-color-l: var(--bulma-danger-dark-invert-l);
}
.button.is-danger.is-soft {
  --bulma-button-background-l: var(--bulma-soft-l);
  --bulma-button-color-l: var(--bulma-soft-invert-l);
}
.button.is-danger.is-bold {
  --bulma-button-background-l: var(--bulma-bold-l);
  --bulma-button-color-l: var(--bulma-bold-invert-l);
}
.button.is-danger[disabled], fieldset[disabled] .button.is-danger {
  background-color: var(--bulma-danger);
  border-color: var(--bulma-danger);
  box-shadow: none;
}
.button.is-outlined {
  --bulma-button-border-width: max(1px, 0.0625em);
  background-color: transparent;
  border-color: hsl(var(--bulma-button-h), var(--bulma-button-s), var(--bulma-button-l));
  color: hsl(var(--bulma-button-h), var(--bulma-button-s), var(--bulma-button-l));
}
.button.is-outlined:hover {
  --bulma-button-border-width: max(2px, 0.125em);
  --bulma-button-outer-shadow-alpha: 1;
}
.button.is-inverted {
  background-color: hsl(var(--bulma-button-h), var(--bulma-button-s), calc(var(--bulma-button-color-l) + var(--bulma-button-background-l-delta)));
  color: hsl(var(--bulma-button-h), var(--bulma-button-s), var(--bulma-button-background-l));
}
.button.is-text {
  background-color: transparent;
  border-color: transparent;
  color: var(--bulma-button-text-color);
  text-decoration: var(--bulma-button-text-decoration);
}
.button.is-text:hover, .button.is-text.is-hovered {
  background-color: var(--bulma-button-text-hover-background-color);
  color: var(--bulma-button-text-hover-color);
}
.button.is-text:active, .button.is-text.is-active {
  color: var(--bulma-button-text-hover-color);
}
.button.is-text[disabled], fieldset[disabled] .button.is-text {
  background-color: transparent;
  border-color: transparent;
  box-shadow: none;
}
.button.is-ghost {
  background: var(--bulma-button-ghost-background);
  border-color: var(--bulma-button-ghost-border-color);
  box-shadow: none;
  color: var(--bulma-button-ghost-color);
  text-decoration: var(--bulma-button-ghost-decoration);
}
.button.is-ghost:hover, .button.is-ghost.is-hovered {
  color: var(--bulma-button-ghost-hover-color);
  text-decoration: var(--bulma-button-ghost-hover-decoration);
}
.button.is-small {
  --bulma-control-size: var(--bulma-size-small);
  --bulma-control-radius: var(--bulma-radius-small);
}
.button.is-normal {
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-radius: var(--bulma-radius);
}
.button.is-medium {
  --bulma-control-size: var(--bulma-size-medium);
  --bulma-control-radius: var(--bulma-radius-medium);
}
.button.is-large {
  --bulma-control-size: var(--bulma-size-large);
  --bulma-control-radius: var(--bulma-radius-medium);
}
.button.is-fullwidth {
  display: flex;
  width: 100%;
}
.button.is-loading {
  box-shadow: none;
  color: transparent !important;
  pointer-events: none;
}
.button.is-loading::after {
  position: absolute;
  left: calc(50% - 1em * 0.5);
  top: calc(50% - 1em * 0.5);
  position: absolute !important;
}
.button.is-static {
  background-color: var(--bulma-button-static-background-color);
  border-color: var(--bulma-button-static-border-color);
  color: var(--bulma-button-static-color);
  box-shadow: none;
  pointer-events: none;
}
.button.is-rounded {
  border-radius: var(--bulma-radius-rounded);
  padding-left: calc(var(--bulma-button-padding-horizontal) + 0.25em - var(--bulma-button-border-width));
  padding-right: calc(var(--bulma-button-padding-horizontal) + 0.25em - var(--bulma-button-border-width));
}

.buttons {
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  gap: 0.75rem;
  justify-content: flex-start;
}
.buttons.are-small {
  --bulma-control-size: var(--bulma-size-small);
  --bulma-control-radius: var(--bulma-radius-small);
}
.buttons.are-medium {
  --bulma-control-size: var(--bulma-size-medium);
  --bulma-control-radius: var(--bulma-radius-medium);
}
.buttons.are-large {
  --bulma-control-size: var(--bulma-size-large);
  --bulma-control-radius: var(--bulma-radius-large);
}
.buttons.has-addons {
  gap: 0;
}
.buttons.has-addons .button:not(:first-child) {
  border-end-start-radius: 0;
  border-start-start-radius: 0;
}
.buttons.has-addons .button:not(:last-child) {
  border-end-end-radius: 0;
  border-start-end-radius: 0;
  margin-inline-end: -1px;
}
.buttons.has-addons .button:hover, .buttons.has-addons .button.is-hovered {
  z-index: 2;
}
.buttons.has-addons .button:focus, .buttons.has-addons .button.is-focused, .buttons.has-addons .button:active, .buttons.has-addons .button.is-active, .buttons.has-addons .button.is-selected {
  z-index: 3;
}
.buttons.has-addons .button:focus:hover, .buttons.has-addons .button.is-focused:hover, .buttons.has-addons .button:active:hover, .buttons.has-addons .button.is-active:hover, .buttons.has-addons .button.is-selected:hover {
  z-index: 4;
}
.buttons.has-addons .button.is-expanded {
  flex-grow: 1;
  flex-shrink: 1;
}
.buttons.is-centered {
  justify-content: center;
}
.buttons.is-right {
  justify-content: flex-end;
}

@media screen and (max-width: 768px) {
  .button.is-responsive.is-small {
    font-size: calc(var(--bulma-size-small) * 0.75);
  }
  .button.is-responsive,
  .button.is-responsive.is-normal {
    font-size: calc(var(--bulma-size-small) * 0.875);
  }
  .button.is-responsive.is-medium {
    font-size: var(--bulma-size-small);
  }
  .button.is-responsive.is-large {
    font-size: var(--bulma-size-normal);
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .button.is-responsive.is-small {
    font-size: calc(var(--bulma-size-small) * 0.875);
  }
  .button.is-responsive,
  .button.is-responsive.is-normal {
    font-size: var(--bulma-size-small);
  }
  .button.is-responsive.is-medium {
    font-size: var(--bulma-size-normal);
  }
  .button.is-responsive.is-large {
    font-size: var(--bulma-size-medium);
  }
}

/*# sourceMappingURL=button.css.map */
