:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.box:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.box {
  --bulma-box-background-color: var(--bulma-scheme-main);
  --bulma-box-color: var(--bulma-text);
  --bulma-box-radius: var(--bulma-radius-large);
  --bulma-box-shadow: var(--bulma-shadow);
  --bulma-box-padding: 1.25rem;
  --bulma-box-link-hover-shadow: 0 0.5em 1em -0.125em hsla(var(--bulma-scheme-h), var(--bulma-scheme-s), var(--bulma-scheme-invert-l), 0.1), 0 0 0 1px var(--bulma-link);
  --bulma-box-link-active-shadow: inset 0 1px 2px hsla(var(--bulma-scheme-h), var(--bulma-scheme-s), var(--bulma-scheme-invert-l), 0.2), 0 0 0 1px var(--bulma-link);
}

.box {
  background-color: var(--bulma-box-background-color);
  border-radius: var(--bulma-box-radius);
  box-shadow: var(--bulma-box-shadow);
  color: var(--bulma-box-color);
  display: block;
  padding: var(--bulma-box-padding);
}

a.box:hover, a.box:focus {
  box-shadow: var(--bulma-box-link-hover-shadow);
}
a.box:active {
  box-shadow: var(--bulma-box-link-active-shadow);
}

/*# sourceMappingURL=box.css.map */
