.footer {
  --bulma-footer-background-color: var(--bulma-scheme-main-bis);
  --bulma-footer-color: false;
  --bulma-footer-padding: 3rem 1.5rem 6rem;
  background-color: var(--bulma-footer-background-color);
  padding: var(--bulma-footer-padding);
}

/*# sourceMappingURL=footer.css.map */
