:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.pagination:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.pagination-previous,
.pagination-next,
.pagination-link,
.pagination-ellipsis {
  align-items: center;
  appearance: none;
  border-color: transparent;
  border-style: solid;
  border-width: var(--bulma-control-border-width);
  border-radius: var(--bulma-control-radius);
  box-shadow: none;
  display: inline-flex;
  font-size: var(--bulma-control-size);
  height: var(--bulma-control-height);
  justify-content: flex-start;
  line-height: var(--bulma-control-line-height);
  padding-bottom: var(--bulma-control-padding-vertical);
  padding-left: var(--bulma-control-padding-horizontal);
  padding-right: var(--bulma-control-padding-horizontal);
  padding-top: var(--bulma-control-padding-vertical);
  position: relative;
  transition-duration: var(--bulma-duration);
  transition-property: background-color, border-color, box-shadow, color;
  vertical-align: top;
}
.pagination-previous:focus,
.pagination-next:focus,
.pagination-link:focus,
.pagination-ellipsis:focus, .pagination-previous:focus-visible,
.pagination-next:focus-visible,
.pagination-link:focus-visible,
.pagination-ellipsis:focus-visible, .pagination-previous:focus-within,
.pagination-next:focus-within,
.pagination-link:focus-within,
.pagination-ellipsis:focus-within, .is-focused.pagination-previous,
.is-focused.pagination-next,
.is-focused.pagination-link,
.is-focused.pagination-ellipsis, .pagination-previous:active,
.pagination-next:active,
.pagination-link:active,
.pagination-ellipsis:active, .is-active.pagination-previous,
.is-active.pagination-next,
.is-active.pagination-link,
.is-active.pagination-ellipsis {
  outline: none;
}
[disabled].pagination-previous,
[disabled].pagination-next,
[disabled].pagination-link,
[disabled].pagination-ellipsis, fieldset[disabled] .pagination-previous,
fieldset[disabled] .pagination-next,
fieldset[disabled] .pagination-link,
fieldset[disabled] .pagination-ellipsis {
  cursor: not-allowed;
}

.pagination-previous,
.pagination-next,
.pagination-link,
.pagination-ellipsis {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.pagination {
  --bulma-pagination-margin: -0.25rem;
  --bulma-pagination-min-width: var(--bulma-control-height);
  --bulma-pagination-item-h: var(--bulma-scheme-h);
  --bulma-pagination-item-s: var(--bulma-scheme-s);
  --bulma-pagination-item-l: var(--bulma-scheme-main-l);
  --bulma-pagination-item-background-l-delta: 0%;
  --bulma-pagination-item-hover-background-l-delta: var(--bulma-hover-background-l-delta);
  --bulma-pagination-item-active-background-l-delta: var(--bulma-active-background-l-delta);
  --bulma-pagination-item-border-style: solid;
  --bulma-pagination-item-border-width: var(--bulma-control-border-width);
  --bulma-pagination-item-border-l: var(--bulma-border-l);
  --bulma-pagination-item-border-l-delta: 0%;
  --bulma-pagination-item-hover-border-l-delta: var(--bulma-hover-border-l-delta);
  --bulma-pagination-item-active-border-l-delta: var(--bulma-active-border-l-delta);
  --bulma-pagination-item-focus-border-l-delta: var(--bulma-focus-border-l-delta);
  --bulma-pagination-item-color-l: var(--bulma-text-strong-l);
  --bulma-pagination-item-font-size: 1em;
  --bulma-pagination-item-margin: 0.25rem;
  --bulma-pagination-item-padding-left: 0.5em;
  --bulma-pagination-item-padding-right: 0.5em;
  --bulma-pagination-item-outer-shadow-h: 0;
  --bulma-pagination-item-outer-shadow-s: 0%;
  --bulma-pagination-item-outer-shadow-l: 20%;
  --bulma-pagination-item-outer-shadow-a: 0.05;
  --bulma-pagination-nav-padding-left: 0.75em;
  --bulma-pagination-nav-padding-right: 0.75em;
  --bulma-pagination-disabled-color: var(--bulma-text-weak);
  --bulma-pagination-disabled-background-color: var(--bulma-border);
  --bulma-pagination-disabled-border-color: var(--bulma-border);
  --bulma-pagination-current-color: var(--bulma-link-invert);
  --bulma-pagination-current-background-color: var(--bulma-link);
  --bulma-pagination-current-border-color: var(--bulma-link);
  --bulma-pagination-ellipsis-color: var(--bulma-text-weak);
  --bulma-pagination-shadow-inset: inset 0 0.0625em 0.125em hsla(var(--bulma-scheme-h), var(--bulma-scheme-s), var(--bulma-scheme-invert-l), 0.2);
  --bulma-pagination-selected-item-h: var(--bulma-link-h);
  --bulma-pagination-selected-item-s: var(--bulma-link-s);
  --bulma-pagination-selected-item-l: var(--bulma-link-l);
  --bulma-pagination-selected-item-background-l: var(--bulma-link-l);
  --bulma-pagination-selected-item-border-l: var(--bulma-link-l);
  --bulma-pagination-selected-item-color-l: var(--bulma-link-invert-l);
}

.pagination {
  font-size: var(--bulma-size-normal);
  margin: var(--bulma-pagination-margin);
}
.pagination.is-small {
  font-size: var(--bulma-size-small);
}
.pagination.is-medium {
  font-size: var(--bulma-size-medium);
}
.pagination.is-large {
  font-size: var(--bulma-size-large);
}
.pagination.is-rounded .pagination-previous,
.pagination.is-rounded .pagination-next {
  padding-left: 1em;
  padding-right: 1em;
  border-radius: var(--bulma-radius-rounded);
}
.pagination.is-rounded .pagination-link {
  border-radius: var(--bulma-radius-rounded);
}

.pagination,
.pagination-list {
  align-items: center;
  display: flex;
  justify-content: center;
  text-align: center;
}

.pagination-previous,
.pagination-next,
.pagination-link,
.pagination-ellipsis {
  color: hsl(var(--bulma-pagination-item-h), var(--bulma-pagination-item-s), var(--bulma-pagination-item-color-l));
  font-size: var(--bulma-pagination-item-font-size);
  justify-content: center;
  margin: var(--bulma-pagination-item-margin);
  padding-left: var(--bulma-pagination-item-padding-left);
  padding-right: var(--bulma-pagination-item-padding-right);
  text-align: center;
}

.pagination-previous,
.pagination-next,
.pagination-link {
  background-color: hsl(var(--bulma-pagination-item-h), var(--bulma-pagination-item-s), calc(var(--bulma-pagination-item-background-l) + var(--bulma-pagination-item-background-l-delta)));
  border-color: hsl(var(--bulma-pagination-item-h), var(--bulma-pagination-item-s), calc(var(--bulma-pagination-item-border-l) + var(--bulma-pagination-item-border-l-delta)));
  border-style: var(--bulma-pagination-item-border-style);
  border-width: var(--bulma-pagination-item-border-width);
  box-shadow: 0px 0.0625em 0.125em hsla(var(--bulma-pagination-item-outer-shadow-h), var(--bulma-pagination-item-outer-shadow-s), var(--bulma-pagination-item-outer-shadow-l), var(--bulma-pagination-item-outer-shadow-a)), 0px 0.125em 0.25em hsla(var(--bulma-pagination-item-outer-shadow-h), var(--bulma-pagination-item-outer-shadow-s), var(--bulma-pagination-item-outer-shadow-l), var(--bulma-pagination-item-outer-shadow-a));
  color: hsl(var(--bulma-pagination-item-h), var(--bulma-pagination-item-s), var(--bulma-pagination-item-color-l));
  min-width: var(--bulma-pagination-min-width);
  transition-duration: var(--bulma-duration);
  transition-property: background-color, border-color, box-shadow, color;
}
.pagination-previous:hover,
.pagination-next:hover,
.pagination-link:hover {
  --bulma-pagination-item-background-l-delta: var(--bulma-pagination-item-hover-background-l-delta);
  --bulma-pagination-item-border-l-delta: var(--bulma-pagination-item-hover-border-l-delta);
}
.pagination-previous:focus,
.pagination-next:focus,
.pagination-link:focus {
  --bulma-pagination-item-background-l-delta: var(--bulma-pagination-item-hover-background-l-delta);
  --bulma-pagination-item-border-l-delta: var(--bulma-pagination-item-hover-border-l-delta);
}
.pagination-previous:active,
.pagination-next:active,
.pagination-link:active {
  box-shadow: var(--bulma-pagination-shadow-inset);
}
.pagination-previous[disabled], .pagination-previous.is-disabled,
.pagination-next[disabled],
.pagination-next.is-disabled,
.pagination-link[disabled],
.pagination-link.is-disabled {
  background-color: var(--bulma-pagination-disabled-background-color);
  border-color: var(--bulma-pagination-disabled-border-color);
  box-shadow: none;
  color: var(--bulma-pagination-disabled-color);
  opacity: 0.5;
}

.pagination-previous,
.pagination-next {
  padding-left: var(--bulma-pagination-nav-padding-left);
  padding-right: var(--bulma-pagination-nav-padding-right);
  white-space: nowrap;
}

.pagination-link.is-current, .pagination-link.is-selected {
  --bulma-pagination-item-h: var(--bulma-pagination-selected-item-h);
  --bulma-pagination-item-s: var(--bulma-pagination-selected-item-s);
  --bulma-pagination-item-l: var(--bulma-pagination-selected-item-l);
  --bulma-pagination-item-background-l: var(--bulma-pagination-selected-item-background-l);
  --bulma-pagination-item-border-l: var(--bulma-pagination-selected-item-border-l);
  --bulma-pagination-item-color-l: var(--bulma-pagination-selected-item-color-l);
}

.pagination-ellipsis {
  color: var(--bulma-pagination-ellipsis-color);
  pointer-events: none;
}

.pagination-list {
  flex-wrap: wrap;
}
.pagination-list li {
  list-style: none;
}

@media screen and (max-width: 768px) {
  .pagination {
    flex-wrap: wrap;
  }
  .pagination-previous,
  .pagination-next {
    flex-grow: 1;
    flex-shrink: 1;
  }
  .pagination-list li {
    flex-grow: 1;
    flex-shrink: 1;
  }
}
@media screen and (min-width: 769px), print {
  .pagination-list {
    flex-grow: 1;
    flex-shrink: 1;
    justify-content: flex-start;
    order: 1;
  }
  .pagination-previous,
  .pagination-next,
  .pagination-link,
  .pagination-ellipsis {
    margin-bottom: 0;
    margin-top: 0;
  }
  .pagination-previous {
    order: 2;
  }
  .pagination-next {
    order: 3;
  }
  .pagination {
    justify-content: space-between;
    margin-bottom: 0;
    margin-top: 0;
  }
  .pagination.is-centered .pagination-previous {
    order: 1;
  }
  .pagination.is-centered .pagination-list {
    justify-content: center;
    order: 2;
  }
  .pagination.is-centered .pagination-next {
    order: 3;
  }
  .pagination.is-right .pagination-previous {
    order: 1;
  }
  .pagination.is-right .pagination-next {
    order: 2;
  }
  .pagination.is-right .pagination-list {
    justify-content: flex-end;
    order: 3;
  }
}

/*# sourceMappingURL=pagination.css.map */
