:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.file:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.file-cta,
.file-name {
  align-items: center;
  appearance: none;
  border-color: transparent;
  border-style: solid;
  border-width: var(--bulma-control-border-width);
  border-radius: var(--bulma-control-radius);
  box-shadow: none;
  display: inline-flex;
  font-size: var(--bulma-control-size);
  height: var(--bulma-control-height);
  justify-content: flex-start;
  line-height: var(--bulma-control-line-height);
  padding-bottom: var(--bulma-control-padding-vertical);
  padding-left: var(--bulma-control-padding-horizontal);
  padding-right: var(--bulma-control-padding-horizontal);
  padding-top: var(--bulma-control-padding-vertical);
  position: relative;
  transition-duration: var(--bulma-duration);
  transition-property: background-color, border-color, box-shadow, color;
  vertical-align: top;
}
.file-cta:focus,
.file-name:focus, .file-cta:focus-visible,
.file-name:focus-visible, .file-cta:focus-within,
.file-name:focus-within, .is-focused.file-cta,
.is-focused.file-name, .file-cta:active,
.file-name:active, .is-active.file-cta,
.is-active.file-name {
  outline: none;
}
[disabled].file-cta,
[disabled].file-name, fieldset[disabled] .file-cta,
fieldset[disabled] .file-name {
  cursor: not-allowed;
}

.file {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.control,
.input,
.textarea,
.select {
  --bulma-input-h: var(--bulma-scheme-h);
  --bulma-input-s: var(--bulma-scheme-s);
  --bulma-input-l: var(--bulma-scheme-main-l);
  --bulma-input-border-style: solid;
  --bulma-input-border-width: var(--bulma-control-border-width);
  --bulma-input-border-l: var(--bulma-border-l);
  --bulma-input-border-l-delta: 0%;
  --bulma-input-hover-border-l-delta: var(--bulma-hover-border-l-delta);
  --bulma-input-active-border-l-delta: var(--bulma-active-border-l-delta);
  --bulma-input-focus-h: var(--bulma-focus-h);
  --bulma-input-focus-s: var(--bulma-focus-s);
  --bulma-input-focus-l: var(--bulma-focus-l);
  --bulma-input-focus-shadow-size: var(--bulma-focus-shadow-size);
  --bulma-input-focus-shadow-alpha: var(--bulma-focus-shadow-alpha);
  --bulma-input-color-l: var(--bulma-text-strong-l);
  --bulma-input-background-l: var(--bulma-scheme-main-l);
  --bulma-input-background-l-delta: 0%;
  --bulma-input-height: var(--bulma-control-height);
  --bulma-input-shadow: inset 0 0.0625em 0.125em hsla(var(--bulma-scheme-h), var(--bulma-scheme-s), var(--bulma-scheme-invert-l), 0.05);
  --bulma-input-placeholder-color: hsla(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-strong-l), 0.3);
  --bulma-input-disabled-color: var(--bulma-text-weak);
  --bulma-input-disabled-background-color: var(--bulma-background);
  --bulma-input-disabled-border-color: var(--bulma-background);
  --bulma-input-disabled-placeholder-color: hsla(var(--bulma-text-h), var(--bulma-text-s), var(--bulma-text-weak-l), 0.3);
  --bulma-input-arrow: var(--bulma-link);
  --bulma-input-icon-color: var(--bulma-text-light);
  --bulma-input-icon-hover-color: var(--bulma-text-weak);
  --bulma-input-icon-focus-color: var(--bulma-link);
  --bulma-input-radius: var(--bulma-radius);
}

.file {
  --bulma-file-radius: var(--bulma-radius);
  --bulma-file-name-border-color: var(--bulma-border);
  --bulma-file-name-border-style: solid;
  --bulma-file-name-border-width: 1px 1px 1px 0;
  --bulma-file-name-max-width: 16em;
  --bulma-file-h: var(--bulma-scheme-h);
  --bulma-file-s: var(--bulma-scheme-s);
  --bulma-file-background-l: var(--bulma-scheme-main-ter-l);
  --bulma-file-background-l-delta: 0%;
  --bulma-file-hover-background-l-delta: -5%;
  --bulma-file-active-background-l-delta: -10%;
  --bulma-file-border-l: var(--bulma-border-l);
  --bulma-file-border-l-delta: 0%;
  --bulma-file-hover-border-l-delta: -10%;
  --bulma-file-active-border-l-delta: -20%;
  --bulma-file-cta-color-l: var(--bulma-text-strong-l);
  --bulma-file-name-color-l: var(--bulma-text-strong-l);
  --bulma-file-color-l-delta: 0%;
  --bulma-file-hover-color-l-delta: -5%;
  --bulma-file-active-color-l-delta: -10%;
  align-items: stretch;
  display: flex;
  justify-content: flex-start;
  position: relative;
}
.file.is-white {
  --bulma-file-h: var(--bulma-white-h);
  --bulma-file-s: var(--bulma-white-s);
  --bulma-file-background-l: var(--bulma-white-l);
  --bulma-file-border-l: var(--bulma-white-l);
  --bulma-file-cta-color-l: var(--bulma-white-invert-l);
  --bulma-file-name-color-l: var(--bulma-white-on-scheme-l);
}
.file.is-black {
  --bulma-file-h: var(--bulma-black-h);
  --bulma-file-s: var(--bulma-black-s);
  --bulma-file-background-l: var(--bulma-black-l);
  --bulma-file-border-l: var(--bulma-black-l);
  --bulma-file-cta-color-l: var(--bulma-black-invert-l);
  --bulma-file-name-color-l: var(--bulma-black-on-scheme-l);
}
.file.is-light {
  --bulma-file-h: var(--bulma-light-h);
  --bulma-file-s: var(--bulma-light-s);
  --bulma-file-background-l: var(--bulma-light-l);
  --bulma-file-border-l: var(--bulma-light-l);
  --bulma-file-cta-color-l: var(--bulma-light-invert-l);
  --bulma-file-name-color-l: var(--bulma-light-on-scheme-l);
}
.file.is-dark {
  --bulma-file-h: var(--bulma-dark-h);
  --bulma-file-s: var(--bulma-dark-s);
  --bulma-file-background-l: var(--bulma-dark-l);
  --bulma-file-border-l: var(--bulma-dark-l);
  --bulma-file-cta-color-l: var(--bulma-dark-invert-l);
  --bulma-file-name-color-l: var(--bulma-dark-on-scheme-l);
}
.file.is-text {
  --bulma-file-h: var(--bulma-text-h);
  --bulma-file-s: var(--bulma-text-s);
  --bulma-file-background-l: var(--bulma-text-l);
  --bulma-file-border-l: var(--bulma-text-l);
  --bulma-file-cta-color-l: var(--bulma-text-invert-l);
  --bulma-file-name-color-l: var(--bulma-text-on-scheme-l);
}
.file.is-primary {
  --bulma-file-h: var(--bulma-primary-h);
  --bulma-file-s: var(--bulma-primary-s);
  --bulma-file-background-l: var(--bulma-primary-l);
  --bulma-file-border-l: var(--bulma-primary-l);
  --bulma-file-cta-color-l: var(--bulma-primary-invert-l);
  --bulma-file-name-color-l: var(--bulma-primary-on-scheme-l);
}
.file.is-link {
  --bulma-file-h: var(--bulma-link-h);
  --bulma-file-s: var(--bulma-link-s);
  --bulma-file-background-l: var(--bulma-link-l);
  --bulma-file-border-l: var(--bulma-link-l);
  --bulma-file-cta-color-l: var(--bulma-link-invert-l);
  --bulma-file-name-color-l: var(--bulma-link-on-scheme-l);
}
.file.is-info {
  --bulma-file-h: var(--bulma-info-h);
  --bulma-file-s: var(--bulma-info-s);
  --bulma-file-background-l: var(--bulma-info-l);
  --bulma-file-border-l: var(--bulma-info-l);
  --bulma-file-cta-color-l: var(--bulma-info-invert-l);
  --bulma-file-name-color-l: var(--bulma-info-on-scheme-l);
}
.file.is-success {
  --bulma-file-h: var(--bulma-success-h);
  --bulma-file-s: var(--bulma-success-s);
  --bulma-file-background-l: var(--bulma-success-l);
  --bulma-file-border-l: var(--bulma-success-l);
  --bulma-file-cta-color-l: var(--bulma-success-invert-l);
  --bulma-file-name-color-l: var(--bulma-success-on-scheme-l);
}
.file.is-warning {
  --bulma-file-h: var(--bulma-warning-h);
  --bulma-file-s: var(--bulma-warning-s);
  --bulma-file-background-l: var(--bulma-warning-l);
  --bulma-file-border-l: var(--bulma-warning-l);
  --bulma-file-cta-color-l: var(--bulma-warning-invert-l);
  --bulma-file-name-color-l: var(--bulma-warning-on-scheme-l);
}
.file.is-danger {
  --bulma-file-h: var(--bulma-danger-h);
  --bulma-file-s: var(--bulma-danger-s);
  --bulma-file-background-l: var(--bulma-danger-l);
  --bulma-file-border-l: var(--bulma-danger-l);
  --bulma-file-cta-color-l: var(--bulma-danger-invert-l);
  --bulma-file-name-color-l: var(--bulma-danger-on-scheme-l);
}
.file.is-small {
  font-size: var(--bulma-size-small);
}
.file.is-normal {
  font-size: var(--bulma-size-normal);
}
.file.is-medium {
  font-size: var(--bulma-size-medium);
}
.file.is-medium .file-icon .fa {
  font-size: 1.5rem;
}
.file.is-large {
  font-size: var(--bulma-size-large);
}
.file.is-large .file-icon .fa {
  font-size: 2rem;
}
.file.has-name .file-cta {
  border-end-end-radius: 0;
  border-start-end-radius: 0;
}
.file.has-name .file-name {
  border-end-start-radius: 0;
  border-start-start-radius: 0;
}
.file.has-name.is-empty .file-cta {
  border-radius: var(--bulma-file-radius);
}
.file.has-name.is-empty .file-name {
  display: none;
}
.file.is-boxed .file-label {
  flex-direction: column;
}
.file.is-boxed .file-cta {
  flex-direction: column;
  height: auto;
  padding: 1em 3em;
}
.file.is-boxed .file-name {
  border-width: 0 1px 1px;
}
.file.is-boxed .file-icon {
  height: 1.5em;
  width: 1.5em;
}
.file.is-boxed .file-icon .fa {
  font-size: 1.5rem;
}
.file.is-boxed.is-small .file-icon .fa {
  font-size: 1rem;
}
.file.is-boxed.is-medium .file-icon .fa {
  font-size: 2rem;
}
.file.is-boxed.is-large .file-icon .fa {
  font-size: 2.5rem;
}
.file.is-boxed.has-name .file-cta {
  border-end-end-radius: 0;
  border-end-start-radius: 0;
  border-start-end-radius: var(--bulma-file-radius);
  border-start-start-radius: var(--bulma-file-radius);
}
.file.is-boxed.has-name .file-name {
  border-end-end-radius: var(--bulma-file-radius);
  border-end-start-radius: var(--bulma-file-radius);
  border-start-end-radius: 0;
  border-start-start-radius: 0;
  border-width: 0 1px 1px;
}
.file.is-centered {
  justify-content: center;
}
.file.is-fullwidth .file-label {
  width: 100%;
}
.file.is-fullwidth .file-name {
  flex-grow: 1;
  max-width: none;
}
.file.is-right {
  justify-content: flex-end;
}
.file.is-right .file-cta {
  border-radius: 0 var(--bulma-file-radius) var(--bulma-file-radius) 0;
}
.file.is-right .file-name {
  border-radius: var(--bulma-file-radius) 0 0 var(--bulma-file-radius);
  border-width: 1px 0 1px 1px;
  order: -1;
}

.file-label {
  align-items: stretch;
  display: flex;
  cursor: pointer;
  justify-content: flex-start;
  overflow: hidden;
  position: relative;
}
.file-label:hover {
  --bulma-file-background-l-delta: var(--bulma-file-hover-background-l-delta);
  --bulma-file-border-l-delta: var(--bulma-file-hover-border-l-delta);
  --bulma-file-color-l-delta: var(--bulma-file-hover-color-l-delta);
}
.file-label:active {
  --bulma-file-background-l-delta: var(--bulma-file-active-background-l-delta);
  --bulma-file-border-l-delta: var(--bulma-file-active-border-l-delta);
  --bulma-file-color-l-delta: var(--bulma-file-active-color-l-delta);
}

.file-input {
  height: 100%;
  left: 0;
  opacity: 0;
  outline: none;
  position: absolute;
  top: 0;
  width: 100%;
}

.file-cta,
.file-name {
  border-color: hsl(var(--bulma-file-h), var(--bulma-file-s), calc(var(--bulma-file-border-l) + var(--bulma-file-border-l-delta)));
  border-radius: var(--bulma-file-radius);
  font-size: 1em;
  padding-left: 1em;
  padding-right: 1em;
  white-space: nowrap;
}

.file-cta {
  background-color: hsl(var(--bulma-file-h), var(--bulma-file-s), calc(var(--bulma-file-background-l) + var(--bulma-file-background-l-delta)));
  color: hsl(var(--bulma-file-h), var(--bulma-file-s), calc(var(--bulma-file-cta-color-l) + var(--bulma-file-color-l-delta)));
}

.file-name {
  border-color: hsl(var(--bulma-file-h), var(--bulma-file-s), calc(var(--bulma-file-border-l) + var(--bulma-file-color-l-delta)));
  border-style: var(--bulma-file-name-border-style);
  border-width: var(--bulma-file-name-border-width);
  color: hsl(var(--bulma-file-h), var(--bulma-file-s), calc(var(--bulma-file-name-color-l) + var(--bulma-file-color-l-delta)));
  display: block;
  max-width: var(--bulma-file-name-max-width);
  overflow: hidden;
  text-align: inherit;
  text-overflow: ellipsis;
}

.file-icon {
  align-items: center;
  display: flex;
  height: 1em;
  justify-content: center;
  margin-inline-end: 0.5em;
  width: 1em;
}
.file-icon .fa {
  font-size: 1rem;
}

/*# sourceMappingURL=file.css.map */
